==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/AnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var AnchoredCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AnchoredCategorySeriesDescriptionMetadata, _super);
    function AnchoredCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AnchoredCategorySeriesDescriptionMetadata.b = function (a) {
        if (AnchoredCategorySeriesDescriptionMetadata.a == null) {
            AnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AnchoredCategorySeriesDescriptionMetadata.c(AnchoredCategorySeriesDescriptionMetadata.a);
        }
        if (a.g(AnchoredCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(AnchoredCategorySeriesDescriptionMetadata.a);
    };
    AnchoredCategorySeriesDescriptionMetadata.c = function (a) {
        CategorySeriesDescriptionMetadata.c(a);
        a.item("ValueMemberPath", "String");
        a.item("ValueMemberAsLegendLabel", "String");
        a.item("ValueMemberAsLegendUnit", "String");
        a.item("TrendLineType", "ExportedType:string:TrendLineType");
        a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
        a.item("TrendLineBrush", "Brush");
        a.item("ActualTrendLineBrush", "Brush");
        a.item("TrendLineThickness", "Number:double");
        a.item("TrendLinePeriod", "Number:int");
        a.item("MarkerCollisionAvoidance", "ExportedType:string:CategorySeriesMarkerCollisionAvoidance");
        a.item("MarkerCollisionAvoidance@names", "None;Omit");
        a.item("ConsolidatedItemHitTestBehavior", "ExportedType:string:ConsolidatedItemHitTestBehavior");
        a.item("ConsolidatedItemHitTestBehavior@names", "Basic;NearestY");
    };
    AnchoredCategorySeriesDescriptionMetadata.d = function (a) {
        AnchoredCategorySeriesDescriptionMetadata.b(a);
        a.t("AnchoredCategorySeries", AnchoredCategorySeriesDescriptionMetadata.a);
    };
    AnchoredCategorySeriesDescriptionMetadata.$t = markType(AnchoredCategorySeriesDescriptionMetadata, 'AnchoredCategorySeriesDescriptionMetadata');
    AnchoredCategorySeriesDescriptionMetadata.a = null;
    return AnchoredCategorySeriesDescriptionMetadata;
}(Base));
export { AnchoredCategorySeriesDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/AnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var AnchoredCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AnchoredCategorySeriesDescriptionMetadata, _super);
    function AnchoredCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AnchoredCategorySeriesDescriptionMetadata.b = function (a) {
        if (AnchoredCategorySeriesDescriptionMetadata.a == null) {
            AnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AnchoredCategorySeriesDescriptionMetadata.c(AnchoredCategorySeriesDescriptionMetadata.a);
        }
        if (a.j(AnchoredCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(AnchoredCategorySeriesDescriptionMetadata.a);
    };
    AnchoredCategorySeriesDescriptionMetadata.c = function (a) {
        CategorySeriesDescriptionMetadata.c(a);
        a.item("ValueMemberPath", "String");
        a.item("ValueMemberAsLegendLabel", "String");
        a.item("ValueMemberAsLegendUnit", "String");
        a.item("TrendLineType", "ExportedType:string:TrendLineType");
        a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
        a.item("TrendLineBrush", "Brush");
        a.item("ActualTrendLineBrush", "Brush");
        a.item("TrendLineThickness", "Number:double");
        a.item("TrendLinePeriod", "Number:int");
        a.item("MarkerCollisionAvoidance", "ExportedType:string:CategorySeriesMarkerCollisionAvoidance");
        a.item("MarkerCollisionAvoidance@names", "None;Omit");
        a.item("ConsolidatedItemHitTestBehavior", "ExportedType:string:ConsolidatedItemHitTestBehavior");
        a.item("ConsolidatedItemHitTestBehavior@names", "Basic;NearestY");
    };
    AnchoredCategorySeriesDescriptionMetadata.d = function (a) {
        AnchoredCategorySeriesDescriptionMetadata.b(a);
        a.z("AnchoredCategorySeries", AnchoredCategorySeriesDescriptionMetadata.a);
    };
    AnchoredCategorySeriesDescriptionMetadata.$t = markType(AnchoredCategorySeriesDescriptionMetadata, 'AnchoredCategorySeriesDescriptionMetadata');
    AnchoredCategorySeriesDescriptionMetadata.a = null;
    return AnchoredCategorySeriesDescriptionMetadata;
}(Base));
export { AnchoredCategorySeriesDescriptionMetadata };
